#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fsnotify
version:              0.4.4.0
visibility:           public
id:                   fsnotify-0.4.4.0-1VpgVTuAUek2CihiNzra8C
key:                  fsnotify-0.4.4.0-1VpgVTuAUek2CihiNzra8C
license:              BSD-3-Clause
maintainer:           Tom McLaughlin <tom@codedown.io>
author:               Mark Dittmer <mark.s.dittmer@gmail.com>, Niklas Broberg
homepage:             https://github.com/haskell-fswatch/hfsnotify
synopsis:             Cross platform library for file change notification.
description:
    Cross platform library for file creation, modification, and deletion notification. This library builds upon existing libraries for platform-specific Windows, Mac, and Linux filesystem event notification.

category:             Filesystem
abi:                  3dad3dead93f96e40c92e4d91b91522b
exposed:              True
exposed-modules:      System.FSNotify System.FSNotify.Devel
hidden-modules:
    System.FSNotify.Find System.FSNotify.Listener System.FSNotify.Path
    System.FSNotify.Polling System.FSNotify.Types System.FSNotify.Linux
    System.FSNotify.Linux.Util

import-dirs:          /usr/lib/ghc-9.6.6/site-local/fsnotify-0.4.4.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/fsnotify-0.4.4.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/fsnotify-0.4.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fsnotify
hs-libraries:         HSfsnotify-0.4.4.0-1VpgVTuAUek2CihiNzra8C
depends:
    async-2.2.6-FdgrpV5yG9k7PWqxsBsdQu base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.8.5
    filepath-1.4.300.1 hinotify-0.4.2-AUlSOZsxt6gCRumPnyofGf
    monad-control-1.0.3.1-CvSzPldK4ciIr3GPTO2wnc
    safe-exceptions-0.1.7.4-CLdPFV4RmSjLGmeBX34l56 text-2.0.2
    time-1.12.2 unix-2.8.4.0 unix-compat-0.7.4.1-C4WM6snAxnMGmhnzvxcj0k

haddock-interfaces:   /usr/share/doc/haskell-fsnotify/html/fsnotify.haddock
haddock-html:         /usr/share/doc/haskell-fsnotify/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

